Skip to main contentCrate processors_rs
Source - docx_processor
- This module contains the file processor for DOCX files.
- html_processor
- This module contains the file processor for HTML files.
- markdown_processor
- This module contains the file processor for markdown files.
- pdf
- This module contains the file processor for different file types.
- processor
- This library contains the traits and structs used to build a processor for arbitrary contents.
- txt_processor
- This module contains the file processor for text files.